@@ -102,6 +102,9 @@ class EnglishUtils:
         f"^an?[ -]+([^ -].*)$",
         re.IGNORECASE)
 
+    _NOUN_WITH_THAT_OR_WHICH_QUALIFIER = re.compile("^(.*[^,])(,|)[ ]+(that|which)[ ]+(.*)$", re.IGNORECASE)
+    _IS_QUALIFIER = re.compile("^(is|was|has)[ ]+(.*)$", re.IGNORECASE)
+
     @classmethod
     def string_pluralize(cls, word: str, allow_some=False) -> str:
         """
@@ -111,10 +114,30 @@ class EnglishUtils:
               string_pluralize('community') => 'communities'
         """
 
+        qualifier_suffix = ""
+
         charn = word[-1]
         capitalize = word[0].isupper()
         upcase = word.isupper()  # capitalize and not any(ch.islower() for ch in word)
 
+        qual_matched = cls._NOUN_WITH_THAT_OR_WHICH_QUALIFIER.match(word)
+        if qual_matched:
+            qualified, comma, connective, qualifier = qual_matched.groups()
+            word = qualified
+            is_matched = cls._IS_QUALIFIER.match(qualifier)
+            if is_matched:
+                verb, qualifying_adj = is_matched.groups()
+                orig_verb = verb
+                verb = {'is': 'are', 'was': 'were', 'has': 'have'}.get(verb.lower(), verb)
+                if orig_verb[0].isupper():
+                    if orig_verb[-1].isupper():
+                        verb = verb.upper()
+                    else:
+                        verb = verb.capitalize()
+                qualifier = f"{verb} {qualifying_adj}"
+            # Continue to other things after making a verb adjustment
+            qualifier_suffix = f"{comma} {connective} {qualifier}"
+
         # Convert 'a foo' to just 'foo' prior to pluralization. It's pointless to return 'a apples' or 'an apples'.
         # Arguably, we _could_ return 'some apples'
         indef_matched = cls._INDEFINITE_NOUN_REF.match(word)
@@ -122,7 +145,7 @@ class EnglishUtils:
             word = indef_matched.group(1)
             if allow_some:
                 prefix = "SOME " if upcase else ("Some " if capitalize else "some ")
-                return prefix + cls.string_pluralize(word)
+                return prefix + cls.string_pluralize(word) + qualifier_suffix
 
         prep_matched = cls._NOUN_WITH_PREPOSITIONAL_ATTACHMENT.match(word)
         if prep_matched:
@@ -133,11 +156,11 @@ class EnglishUtils:
                 # It's important to do this before calling ourselves recursively to avoid getting 'some' in prep phrases
                 prep_obj = indef_matched.group(1)
                 prep_obj = cls.string_pluralize(prep_obj)
-            return cls.string_pluralize(word) + prep_spacing1 + prep + prep_spacing2 + prep_obj
+            return cls.string_pluralize(word) + prep_spacing1 + prep + prep_spacing2 + prep_obj + qualifier_suffix
 
         result = cls._special_case_plural(word)
         if result:
-            return result
+            return result + qualifier_suffix
 
         if cls._ENDS_IN_FE.match(word):
             result = cls._adjust_ending(word, 2, "ves")
@@ -157,11 +180,11 @@ class EnglishUtils:
             result = cls._adjust_ending(word, 0, "s")
 
         if upcase:
-            return result.upper()
+            return result.upper() + qualifier_suffix
         elif capitalize:
-            return result.capitalize()
+            return result.capitalize() + qualifier_suffix
         else:
-            return result
+            return result + qualifier_suffix
 
     _USE_AN = {}
 
@@ -320,8 +343,8 @@ class EnglishUtils:
 
     @classmethod
     def there_are(cls, items, *, kind: str = "thing", count: Optional[int] = None, there: str = "there",
-                  capitalize=True, joiner=None, zero: object = "no", punctuate=False, use_article=False,
-                  show=True, context=None, tense='present',
+                  capitalize=True, joiner=None, zero: object = "no", punctuate=None, punctuate_none=None,
+                  use_article=False, show=True, context=None, tense='present',
                   **joiner_options) -> str:
         """
         Constructs a sentence that enumerates a set of things.
@@ -334,6 +357,8 @@ class EnglishUtils:
         :param joiner: the joining function to join the items (default if None is just a commas-separated list)
         :param zero: the value to print instead of a numeric zero (default "no")
         :param punctuate: in the case of one or more values (not zero), whether to end with a period (default False)
+        :param punctuate_none: in the case of no values or not showing values, whether to end with a period
+               (default True if show is True, and otherwise is the same as the value of punctuate)
         :param use_article: whether to put 'a' or 'an' in front of each option (default False)
         :param joiner_options: additional (keyword) options to be used with a joiner function if one is supplied
         :param show: whether to show the items if there are any (default True)
@@ -360,6 +385,12 @@ class EnglishUtils:
 
         """
 
+        if punctuate is None:
+            punctuate = False if show else True
+
+        if punctuate_none is None:
+            punctuate_none = True if show else punctuate
+
         there = capitalize1(there) if capitalize else there
         n = len(items) if count is None else count
         # If the items is not in the tenses table, it's assumed to be a modal like 'might', 'may', 'must', 'can' etc.
@@ -368,7 +399,8 @@ class EnglishUtils:
         if context:
             part1 += f" {context}"
         if n == 0 or not show:
-            return part1 + "."
+            punctuation = "." if punctuate_none else ""
+            return part1 + punctuation
         else:
             if use_article:
                 items = [a_or_an(str(item)) for item in items]
@@ -425,6 +457,24 @@ class EnglishUtils:
         result = ", ".join(result)
         return result
 
+    @classmethod
+    def parse_relative_time_string(cls, s):
+        parts = [x for x in s.split(' ') if x != '']
+        if len(parts) % 2 != 0:
+            raise ValueError(f"Relative time strings are an even number of tokens"
+                             f" of the form '<n1> <unit1> <n2> <unit2>...': {s!r}")
+        kwargs = {}
+        for i in range(len(parts) // 2):
+            # Canonicalize "1 week" or "1 weeks" to "weeks": 1.0 for inclusion as kwarg to to timedelta
+            # Uses specialized knowledge that all time units don't end in "s" but pluralize with "+s"
+            value = float(parts[2 * i])
+            units = parts[2 * i + 1].rstrip(',s') + "s"
+            kwargs[units] = value
+        try:
+            return datetime.timedelta(**kwargs)
+        except Exception:
+            raise ValueError(f"Bad relative time string: {s!r}")
+
     @classmethod
     def disjoined_list(cls, items, conjunction: str = 'or', comma: Union[bool, str] = ",",
                        oxford_comma: Union[bool, str] = False, whitespace: str = " ",
@@ -544,6 +594,7 @@ conjoined_list = EnglishUtils.conjoined_list
 disjoined_list = EnglishUtils.disjoined_list
 
 relative_time_string = EnglishUtils.relative_time_string
+parse_relative_time_string = EnglishUtils.parse_relative_time_string
 
 select_a_or_an = EnglishUtils.select_a_or_an
 
